@@ -29,7 +29,7 @@
      Add -r flag: Keith Owens <kaos@ocs.com.au> October 1999.
    */
 
-#ident "$Id: depmod.c 1.3 Tue, 12 Oct 1999 20:53:21 +1000 keith $"
+#ident "$Id: depmod.c 1.4 Mon, 22 Nov 1999 01:38:27 +1100 keith $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -45,6 +45,7 @@
 #include <syslog.h>
 #include <elf.h>
 #include ELF_MACHINE_H
+#include <sys/utsname.h>
 
 #include "module.h"
 #include "version.h"
@@ -53,6 +54,14 @@
 #include "config.h"
 #include "modstat.h"
 
+#if defined(COMBINE_sparc)
+#if defined(ARCH_sparc)
+#define main depmod32_main
+#elif defined(ARCH_sparc64)
+#define main depmod64_main
+#endif
+#endif
+
 #define ALLOC_MODULE	5000	/* Number of modules we can handle... */
 #define ALLOC_SYM	10000	/* Number of symbols allocated per chunk */
 
@@ -699,3 +708,21 @@ int main(int argc, char *argv[])
 
 	return ret;
 }
+
+#if defined(COMBINE_sparc) && defined(ARCH_sparc)
+
+#undef main
+
+extern int depmod64_main(int argc, char **argv);
+
+int
+main(int argc, char **argv)
+{
+	struct utsname u;
+  
+	if (!uname (&u) && !strcmp (u.machine, "sparc64"))
+		return depmod64_main(argc, argv);
+	else
+		return depmod32_main(argc, argv);
+}
+#endif
