@@ -37,7 +37,7 @@
      Add -r flag: Keith Owens <kaos@ocs.com.au> October 1999.
    */
 
-#ident "$Id: insmod.c 1.5 Tue, 12 Oct 1999 20:53:21 +1000 keith $"
+#ident "$Id: insmod.c 1.6 Mon, 22 Nov 1999 01:38:27 +1100 keith $"
 
 #include <sys/types.h>
 #include <stdlib.h>
@@ -51,6 +51,7 @@
 #include <getopt.h>
 #include <sys/stat.h>
 #include <sys/file.h>
+#include <sys/utsname.h>
 
 #include "module.h"
 #include "obj.h"
@@ -60,7 +61,13 @@
 #include "modstat.h"
 #include "config.h"
 
-#if defined(COMBINE_rmmod) || defined(COMBINE_modprobe) || defined(COMBINE_ksyms) || defined(COMBINE_lsmod)
+#if defined(COMBINE_sparc)
+#if defined(ARCH_sparc)
+#define main insmod32_main
+#elif defined(ARCH_sparc64)
+#define main insmod64_main
+#endif
+#elif defined(COMBINE_rmmod) || defined(COMBINE_modprobe) || defined(COMBINE_ksyms) || defined(COMBINE_lsmod)
 #define main insmod_main
 #endif
 
@@ -68,12 +75,12 @@
 
 /*======================================================================*/
 
-int flag_force_load = 0;
-int flag_silent_poll = 0;
-int flag_verbose = 0;
-int flag_export = 1;
-int flag_load_map = 0;
-int flag_ksymoops = 1;
+static int flag_force_load = 0;
+static int flag_silent_poll = 0;
+static int flag_verbose = 0;
+static int flag_export = 1;
+static int flag_load_map = 0;
+static int flag_ksymoops = 1;
 
 static int n_ext_modules_used;
 static int m_has_modinfo;
@@ -267,9 +274,9 @@ static void print_load_map(struct obj_file *f)
 
 		lprintf("%-16s%08lx  %0*lx  2**%d",
 			sec->name,
-			(tgt_long)sec->header.sh_size,
+			(long)sec->header.sh_size,
 			(int) (2 * sizeof(void *)),
-			(tgt_long)sec->header.sh_addr,
+			(long)sec->header.sh_addr,
 			a);
 	}
 
@@ -629,9 +636,9 @@ static void add_ksymoops_symbols(struct obj_file *f, const char *filename, const
 				8+			/* length in dec */
 				1;			/* nul */
 			name = xmalloc(l);
-			snprintf(name, l, "%s%s_S%s_L%d",
+			snprintf(name, l, "%s%s_S%s_L%ld",
 				 symprefix, m_name, sec->name,
-				 sec->header.sh_size);
+				 (long)sec->header.sh_size);
 			sym = obj_add_symbol(f, name, -1, ELFW(ST_INFO) (STB_GLOBAL, STT_NOTYPE),
 					     sec->idx, sec->header.sh_addr, 0);
 			if (use_ksymtab)
@@ -1390,6 +1397,28 @@ int main(int argc, char **argv)
 	return exit_status;
 }
 
+#if defined(COMBINE_sparc) && defined(ARCH_sparc)
+extern int insmod64_main(int argc, char **argv);
+
+#undef main
+
+#if defined(COMBINE_rmmod) || defined(COMBINE_modprobe) || defined(COMBINE_ksyms) || defined(COMBINE_lsmod)
+#define main insmod_main
+#endif
+
+int main(int argc, char **argv)
+{
+	struct utsname u;
+	  
+	if (!uname (&u) && !strcmp (u.machine, "sparc64"))
+		return insmod64_main(argc, argv);
+	else
+		return insmod32_main(argc, argv);
+}
+
+#endif
+
+#if !defined(COMBINE_sparc) || !defined(ARCH_sparc64)
 #if defined(COMBINE_rmmod) || defined(COMBINE_modprobe) || defined(COMBINE_ksyms) || defined(COMBINE_lsmod)
 
 #undef main
@@ -1413,7 +1442,7 @@ int main(int argc, char **argv)
 
 	p = p ? p + 1 : argv[0];
 
-	if (strcmp(p, "insmod") == 0)
+	if (strcmp(p, "insmod") == 0 || strcmp(p, "insmod.static") == 0)
 		return insmod_main(argc, argv);
 #ifdef COMBINE_modprobe
 	else if (strcmp(p, "modprobe") == 0)
@@ -1452,3 +1481,4 @@ int main(int argc, char **argv)
 }
 
 #endif /* Combined executables */
+#endif
