@@ -27,7 +27,7 @@
  * unified module path handling: Bjorn Ekwall <bj0rn@blox.se> February 1999
  */
 
-#ident "$Id: modinfo.c 1.1 Wed, 25 Aug 1999 16:26:49 +1000 keith $"
+#ident "$Id: modinfo.c 1.2 Mon, 22 Nov 1999 01:38:27 +1100 keith $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -37,6 +37,7 @@
 #include <unistd.h>
 #include <sys/param.h>
 #include <sys/stat.h>
+#include <sys/utsname.h>
 
 #include "module.h"
 #include "obj.h"
@@ -44,6 +45,14 @@
 #include "version.h"
 #include "config.h"
 
+#if defined(COMBINE_sparc)
+#if defined(ARCH_sparc)
+#define main modinfo32_main
+#elif defined(ARCH_sparc64)
+#define main modinfo64_main
+#endif
+#endif
+
 static char *get_modinfo_value(struct obj_file *f, const char *key)
 {
 	struct obj_section *sec;
@@ -363,3 +372,21 @@ int main(int argc, char *argv[])
 
 	return 0;
 }
+
+#if defined(COMBINE_sparc) && defined(ARCH_sparc)
+
+#undef main
+
+extern int modinfo64_main(int argc, char **argv);
+
+int
+main(int argc, char **argv)
+{
+	struct utsname u;
+  
+	if (!uname (&u) && !strcmp (u.machine, "sparc64"))
+		return modinfo64_main(argc, argv);
+	else
+		return modinfo32_main(argc, argv);
+}
+#endif
