@@ -906,6 +906,7 @@ static int call_rmmod(const char *modname, DESC *desc, int complain)
 		}
 	}
 
+	readcur();
 	return ret;
 }
 
@@ -1121,6 +1122,7 @@ static int insmod(DESC *desc, LINK **new_in_kernel, char *options[])
 	if (ret == 0)
 		*new_in_kernel = linkit(FIRST, desc, *new_in_kernel);
 
+	readcur();
 	return ret;
 }
 
@@ -1295,7 +1297,7 @@ static int modprobe_fromlist(int argc, char *argv[], char *type, int loadall)
 			do {
 				desc = NULL;
 				obj = g->pathv[alt];
-				ret = probe_stack(stripo(g->pathv[0]), obj, options, &desc);
+				ret = probe_stack(stripo(g->pathv[alt]), obj, options, &desc);
 				if (ret >= -1) /* Some success */
 					++loaded;
 			} while (++alt < g->pathc && (ret < -1 || loadall));
